badwing package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   badwing.character
   badwing.characters
   badwing.command
   badwing.level
   badwing.physics
   badwing.player
   badwing.util

Submodules
----------

badwing.app module
------------------

.. automodule:: badwing.app
   :members:
   :undoc-members:
   :show-inheritance:

badwing.assets module
---------------------

.. automodule:: badwing.assets
   :members:
   :undoc-members:
   :show-inheritance:

badwing.background module
-------------------------

.. automodule:: badwing.background
   :members:
   :undoc-members:
   :show-inheritance:

badwing.barrier module
----------------------

.. automodule:: badwing.barrier
   :members:
   :undoc-members:
   :show-inheritance:

badwing.brain module
--------------------

.. automodule:: badwing.brain
   :members:
   :undoc-members:
   :show-inheritance:

badwing.coin module
-------------------

.. automodule:: badwing.coin
   :members:
   :undoc-members:
   :show-inheritance:

badwing.constants module
------------------------

.. automodule:: badwing.constants
   :members:
   :undoc-members:
   :show-inheritance:

badwing.controller module
-------------------------

.. automodule:: badwing.controller
   :members:
   :undoc-members:
   :show-inheritance:

badwing.debug module
--------------------

.. automodule:: badwing.debug
   :members:
   :undoc-members:
   :show-inheritance:

badwing.dialog module
---------------------

.. automodule:: badwing.dialog
   :members:
   :undoc-members:
   :show-inheritance:

badwing.effect module
---------------------

.. automodule:: badwing.effect
   :members:
   :undoc-members:
   :show-inheritance:

badwing.firework module
-----------------------

.. automodule:: badwing.firework
   :members:
   :undoc-members:
   :show-inheritance:

badwing.flag module
-------------------

.. automodule:: badwing.flag
   :members:
   :undoc-members:
   :show-inheritance:

badwing.geom module
-------------------

.. automodule:: badwing.geom
   :members:
   :undoc-members:
   :show-inheritance:

badwing.layer module
--------------------

.. automodule:: badwing.layer
   :members:
   :undoc-members:
   :show-inheritance:

badwing.main module
-------------------

.. automodule:: badwing.main
   :members:
   :undoc-members:
   :show-inheritance:

badwing.model module
--------------------

.. automodule:: badwing.model
   :members:
   :undoc-members:
   :show-inheritance:

badwing.obstacle module
-----------------------

.. automodule:: badwing.obstacle
   :members:
   :undoc-members:
   :show-inheritance:

badwing.particle module
-----------------------

.. automodule:: badwing.particle
   :members:
   :undoc-members:
   :show-inheritance:

badwing.scene module
--------------------

.. automodule:: badwing.scene
   :members:
   :undoc-members:
   :show-inheritance:

badwing.tile module
-------------------

.. automodule:: badwing.tile
   :members:
   :undoc-members:
   :show-inheritance:

badwing.version module
----------------------

.. automodule:: badwing.version
   :members:
   :undoc-members:
   :show-inheritance:

badwing.view module
-------------------

.. automodule:: badwing.view
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: badwing
   :members:
   :undoc-members:
   :show-inheritance:
